
class Function:
    def invoke(self, filename):
        return "<!-- FUNCTION NOT IMPLEMENTED -->"
